@@ -15,10 +15,10 @@
 #'   or \code{"ges"}).
 #' @param format Character string specifying the output format. One of
 #'   \code{"text"}, \code{"markdown"}, \code{"rmarkdown"}, \code{html},
-#'   \code{"latex"}, \code{"docx"} or \code{"plotmath"}.
+#'   \code{"latex"}, \code{"latex_math"}, \code{"docx"} or \code{"plotmath"}.
 #' @param info Logical indicating whether to print a message on the used test
 #'   (default is \code{FALSE})
-#' @param print Logical indicating wheter to print the formatted output via
+#' @param print Logical indicating whether to print the formatted output via
 #'   \code{cat} (\code{TRUE}, default) or return as a data frame.
 #' @examples
 #' # Using the ez package
@@ -43,7 +43,7 @@ anova_apa <- function(x, effect = NULL,
                                    "hf", "none"),
                       es = c("petasq", "pes", "getasq", "ges"),
                       format = c("text", "markdown", "rmarkdown", "html",
-                                 "latex", "docx", "plotmath"),
+                                 "latex", "latex_math", "docx", "plotmath"),
                       info = FALSE, print = TRUE)
 {
   sph_corr <- match.arg(sph_corr)
@@ -59,7 +59,7 @@ anova_apa <- function(x, effect = NULL,
   {
     anova_apa_aov(x, effect, es, format, info, print)
   }
-  if (inherits(x, c("aovlist", "listof")))
+  else if (inherits(x, c("aovlist", "listof")))
   {
     anova_apa_aovlist(x, effect, sph_corr, es, format, info, print)
   }
@@ -388,14 +388,18 @@ anova_apa_print <- function(tbl, effect, es_name, format, print)
                    tbl$statistic, ", ", fmt_symb("p", format), " ", tbl$p, ", ",
                    fmt_symb(es_name, format), " ", tbl$es)
 
-    if (format == "plotmath")
-    {
-      return(anova_apa_print_plotmath(tbl, text, effect))
-    }
-    else if (format == "latex")
+    if (format == "latex")
     {
       text <- map_chr(text, fmt_latex)
     }
+    else if (format == "latex_math")
+    {
+      text <- map_chr(text, fmt_latex_math)
+    }
+    else if (format == "plotmath")
+    {
+      return(anova_apa_print_plotmath(tbl, text, effect))
+    }
 
     # cat to console
     if (print)
@@ -416,7 +420,7 @@ anova_apa_print <- function(tbl, effect, es_name, format, print)
       }
       else
       {
-        cat(text[which(tbl$effect == effect)])
+        cat(text[which(tbl$effects == effect)])
       }
     }
     # Return as string(s)
@@ -537,4 +541,3 @@ reorder_anova_tbl <- function(x)
   # Apply new order to 'x'
   x[new_order, ]
 }
-
